/*
 * Copyright 2013, Red Hat, Inc. and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.zanata.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.zanata.common.HasContents;
import org.zanata.common.LocaleId;

/**
 * @author Sean Flanigan <a
 *         href="mailto:sflaniga@redhat.com">sflaniga@redhat.com</a>
 *
 */
public interface ITextFlow extends HasContents {
    public @Nonnull
    LocaleId getLocale();

    public @Nonnull
    String getQualifiedId();

    /**
     * Gets the associated TargetContents for a single locale for this
     * SourceContents. Note that default implementation in HTextFlow requires a
     * lot of database I/O
     *
     * @param localeId
     * @return
     */
    public @Nullable
    ITextFlowTarget getTargetContents(@Nonnull LocaleId localeId);

    /**
     * Gets the associated TargetContents for all available locales for this
     * SourceContents.
     *
     * @return
     */
    public @Nonnull
    Iterable<ITextFlowTarget> getAllTargetContents();
}
